ViewPort

Enum ViewPort 

pub enum ViewPort {
    ManualCentered {
        width: f32,
        height: f32,
    },
    ManualViewport {
        x: f32,
        y: f32,
        width: f32,
        height: f32,
    },
    AutoCentered,
    AutoBoundingBox,
}

Variants



ManualCentered

Create a viewport centered around (0, 0), with size (width, height)

Fields

width: f32
height: f32


ManualViewport

Create a viewport centered around (x, y), with size (width, height)

Fields

width: f32
height: f32


AutoCentered

Create a Viewport centered around (0, 0), with auto size that include all [Shapes][dessin::prelude::Shape]



AutoBoundingBox

Create a Viewport centered around the centered of the shapes, with auto size that include all [Shapes][dessin::prelude::Shape]